﻿using DbContextLib;
using Entities;
using Microsoft.EntityFrameworkCore;
using Model.OrderCriteria;
using Shared;

namespace DbDataManager.Service;

public class SuccessDataService : ISuccessService<SuccessEntity>
{
    private UserDbContext DbContext { get; set; }

    public SuccessDataService(UserDbContext context)
    {
        DbContext = context;
        context.Database.EnsureCreated();
    }

    public IEnumerable<SuccessEntity> GetSuccesses(int page, int number, SuccessOrderCriteria orderCriteria)
    {
        IQueryable<SuccessEntity> query = DbContext.Successes.Skip((page - 1) * number).Take(number);
        switch (orderCriteria)
        {
            case SuccessOrderCriteria.None:
                break;
            case SuccessOrderCriteria.ByUserId:
                query = query.OrderBy(s => s.UserId);
                break;
            case SuccessOrderCriteria.ByInquiryId:
                query = query.OrderBy(s => s.InquiryId);
                break;
            case SuccessOrderCriteria.ByIsFinished:
                query = query.OrderBy(s => s.IsFinished);
                break;
            default:
                break;
        }

        var successes = query.ToList();
        return successes;
    }

    public SuccessEntity GetSuccessByUserId(int id)
    {
        var userEntity = DbContext.Successes.FirstOrDefault(u => u.UserId == id);
        if (userEntity == null)
        {
            throw new ArgumentException("Impossible de trouver le succès", nameof(id));
        }

        return userEntity;
    }

    public SuccessEntity GetSuccessByInquiryId(int id)
    {
        var userEntity = DbContext.Successes.FirstOrDefault(u => u.InquiryId == id);
        if (userEntity == null)
        {
            throw new ArgumentException("Impossible de trouver le succès", nameof(id));
        }

        return userEntity;
    }

    public bool DeleteSuccess(int id)
    {
        var successEntity = DbContext.Successes.FirstOrDefault(u => u.UserId == id);
        if (successEntity == null)
        {
            return false;
        }

        DbContext.Successes.Remove(successEntity);
        DbContext.SaveChangesAsync();
        return true;
    }

    public SuccessEntity UpdateSuccess(int id, SuccessEntity success)
    {
        var updatingSuccess = DbContext.Successes.FirstOrDefault(u => u.UserId == id);
        if (updatingSuccess == null)
        {
            throw new ArgumentException("Impossible de trouver le succès", nameof(id));
        }

        foreach (var pptt in typeof(SuccessEntity).GetProperties().Where(p =>
                     p.CanWrite && p.Name != nameof(SuccessEntity.UserId) && p.Name != nameof(SuccessEntity.InquiryId)))
        {
            pptt.SetValue(updatingSuccess, pptt.GetValue(success));
        }

        DbContext.SaveChangesAsync();
        return updatingSuccess;
    }

    public SuccessEntity CreateSuccess(int userId, int inquiryId, bool isFinished)
    {
        var newSuccessEntity = new SuccessEntity()
        {
            UserId = userId,
            InquiryId = inquiryId,
            IsFinished = isFinished,
        };
        DbContext.Successes.Add(newSuccessEntity);
        DbContext.SaveChangesAsync();
        return newSuccessEntity;
    }
}