using Entities;

namespace TestEF;

public class TestSolutionEntity
{
    private const string _murdererFirstName = "John";
    private const string _murdererLastName = "Doe";
    private const string _murderPlace = "WhiteHouse";
    private const string _murderWeapon = "Nuclear Bomb";
    private const string _explaination = "This is an explaination";
    private const int _inquiryId = 42;
    private static InquiryEntity _inquiry = new InquiryEntity();

    [Fact]
    public void TestDefaultConstructor()
    {
        SolutionEntity solution = new SolutionEntity();
        Assert.Equal(0, solution.OwnerId);
        Assert.Null(solution.Owner);
        Assert.Null(solution.MurdererFirstName);
        Assert.Null(solution.MurdererLastName);
        Assert.Null(solution.MurderPlace);
        Assert.Null(solution.MurderWeapon);
        Assert.Null(solution.Explaination);
    }

    [Fact]
    public void TestConstructorWithOnlyId()
    {
        SolutionEntity solution = new SolutionEntity(_inquiryId);
        Assert.Equal(_inquiryId, solution.OwnerId);
        Assert.Null(solution.Owner);
        Assert.Null(solution.MurdererFirstName);
        Assert.Null(solution.MurdererLastName);
        Assert.Null(solution.MurderPlace);
        Assert.Null(solution.MurderWeapon);
        Assert.Null(solution.Explaination);
    }

    [Fact]
    public void TestConstructorWithoutOwnerId()
    {
        SolutionEntity solution = new SolutionEntity(_inquiry, _murdererFirstName, _murdererLastName, _murderPlace,
            _murderWeapon, _explaination);
        Assert.Equal(0, solution.OwnerId);
        Assert.Equal(_inquiry, solution.Owner);
        Assert.Equal(_murdererFirstName, solution.MurdererFirstName);
        Assert.Equal(_murdererLastName, solution.MurdererLastName);
        Assert.Equal(_murderPlace, solution.MurderPlace);
        Assert.Equal(_murderWeapon, solution.MurderWeapon);
        Assert.Equal(_explaination, solution.Explaination);
    }

    [Fact]
    public void TestConstructorWithAllAttributes()
    {
        SolutionEntity solution = new SolutionEntity(_inquiryId, _inquiry, _murdererFirstName, _murdererLastName,
            _murderPlace, _murderWeapon, _explaination);
        Assert.Equal(_inquiryId, solution.OwnerId);
        Assert.Equal(_inquiry, solution.Owner);
        Assert.Equal(_murdererFirstName, solution.MurdererFirstName);
        Assert.Equal(_murdererLastName, solution.MurdererLastName);
        Assert.Equal(_murderPlace, solution.MurderPlace);
        Assert.Equal(_murderWeapon, solution.MurderWeapon);
        Assert.Equal(_explaination, solution.Explaination);
    }

    [Fact]
    public void Constructor_ShouldSetProperties_WhenCalledWithSixParameters()
    {
        // Arrange
        const int ownerId = 1;
        const string murdererFirstName = "John";
        const string murdererLastName = "Doe";
        const string murderPlace = "WhiteHouse";
        const string murderWeapon = "Nuclear Bomb";
        const string explanation = "This is an explanation";

        // Act
        var solutionEntity = new SolutionEntity(ownerId, murdererFirstName, murdererLastName, murderPlace, murderWeapon,
            explanation);

        // Assert
        Assert.Equal(ownerId, solutionEntity.OwnerId);
        Assert.Equal(murdererFirstName, solutionEntity.MurdererFirstName);
        Assert.Equal(murdererLastName, solutionEntity.MurdererLastName);
        Assert.Equal(murderPlace, solutionEntity.MurderPlace);
        Assert.Equal(murderWeapon, solutionEntity.MurderWeapon);
        Assert.Equal(explanation, solutionEntity.Explaination);
    }
}